@@ -19,6 +19,6 @@
 
 
 __all__ = ['EcosizerEngine', 'createBuilding', 'createSystem']
-from engine.EcosizerEngine import *
-from engine.BuildingCreator import createBuilding
-from engine.SystemCreator import createSystem
\ No newline at end of file
+from .engine.EcosizerEngine import *
+from .engine.BuildingCreator import createBuilding
+from .engine.SystemCreator import createSystem
\ No newline at end of file
